@@ -39,14 +39,14 @@ extern "C" {
  *
  * Format: major * 10000 + minor * 100 + release
  */
-#define RASQAL_VERSION 917
+#define RASQAL_VERSION 919
 
 /**
  * RASQAL_VERSION_STRING:
  *
  * Rasqal library version string
  */
-#define RASQAL_VERSION_STRING "0.9.17"
+#define RASQAL_VERSION_STRING "0.9.19"
 
 /**
  * RASQAL_VERSION_MAJOR:
@@ -67,7 +67,7 @@ extern "C" {
  *
  * Rasqal library release
  */
-#define RASQAL_VERSION_RELEASE 17
+#define RASQAL_VERSION_RELEASE 19
 
 
 /**
@@ -191,6 +191,15 @@ typedef struct rasqal_literal_s rasqal_literal;
  */
 typedef struct rasqal_graph_pattern_s rasqal_graph_pattern;
 
+
+/**
+ * rasqal_variables_table:
+ *
+ * Rasqal variables table class.
+ */
+typedef struct rasqal_variables_table_s rasqal_variables_table;
+
+
 /**
  * rasqal_feature:
  * @RASQAL_FEATURE_NO_NET: Deny network requests.
@@ -248,7 +257,6 @@ typedef enum {
 
 /* forward reference */
 struct rasqal_expression_s;
-typedef struct rasqal_variables_table_s rasqal_variables_table;
 
 /**
  * rasqal_variable:
@@ -258,6 +266,7 @@ typedef struct rasqal_variables_table_s rasqal_variables_table;
  * @offset: Internal.
  * @type: Variable type.
  * @expression: Expression when the variable is a computed SELECT expression 
+ * @user_data: Pointer to user data associated with a variable.  This is not used by rasqal.
  *
  * Binding between a variable name and a value.
  *
@@ -271,6 +280,7 @@ typedef struct {
   int offset;
   rasqal_variable_type type;
   struct rasqal_expression_s* expression;
+  void *user_data;
 } rasqal_variable;
 
 
@@ -295,14 +305,14 @@ typedef enum {
  * rasqal_data_graph:
  * @world: rasqal_world object
  * @uri: source URI
- * @name_uri: name of graph for %RASQAL_DATA_NAMED
+ * @name_uri: name of graph for %RASQAL_DATA_GRAPH_NAMED
  * @flags: %RASQAL_DATA_GRAPH_NAMED or %RASQAL_DATA_GRAPH_BACKGROUND
  *
  * A source of RDF data for querying. 
  *
- * The #uri is the original source (base URI) of the content.  It may
+ * The @uri is the original source (base URI) of the content.  It may
  * also have an additional name @name_uri as long as @flags is
- * %RASQAL_DATA_NAMED
+ * %RASQAL_DATA_GRAPH_NAMED
  */
 typedef struct {
   rasqal_world* world;
@@ -379,6 +389,15 @@ typedef enum {
 
 #define RASQAL_LITERAL_UDT_DEFINED 1
 
+
+/**
+ * rasqal_row:
+ *
+ * Rasqal Result Row class.
+ */
+typedef struct rasqal_row_s rasqal_row;
+
+
 /**
  * rasqal_xsd_decimal:
  *
@@ -631,6 +650,7 @@ typedef unsigned char* (*rasqal_generate_bnodeid_handler)(rasqal_query* query, v
  * @RASQAL_QUERY_VERB_ASK: SPARQL query ask verb.
  * @RASQAL_QUERY_VERB_DELETE: LAQRS query delete verb.
  * @RASQAL_QUERY_VERB_INSERT: LAQRS query insert verb.
+ * @RASQAL_QUERY_VERB_UPDATE: SPARQL 1.1 (draft) update operation
  * @RASQAL_QUERY_VERB_UNKNOWN: Internal
  * @RASQAL_QUERY_VERB_LAST: Internal
  *
@@ -646,12 +666,101 @@ typedef enum {
   RASQAL_QUERY_VERB_ASK       = 4,
   RASQAL_QUERY_VERB_DELETE    = 5,
   RASQAL_QUERY_VERB_INSERT    = 6,
+  RASQAL_QUERY_VERB_UPDATE    = 7,
 
   /* internal */
-  RASQAL_QUERY_VERB_LAST=RASQAL_QUERY_VERB_INSERT
+  RASQAL_QUERY_VERB_LAST = RASQAL_QUERY_VERB_UPDATE
 } rasqal_query_verb;
 
 
+/**
+ * rasqal_query_results_type:
+ * @RASQAL_QUERY_RESULTS_BINDINGS: variable binding
+ * @RASQAL_QUERY_RESULTS_BOOLEAN: a single boolean
+ * @RASQAL_QUERY_RESULTS_GRAPH: an RDF graph
+ * @RASQAL_QUERY_RESULTS_SYNTAX: a syntax
+ *
+ * Query result type.
+ */
+
+typedef enum {
+  RASQAL_QUERY_RESULTS_BINDINGS,
+  RASQAL_QUERY_RESULTS_BOOLEAN,
+  RASQAL_QUERY_RESULTS_GRAPH,
+  RASQAL_QUERY_RESULTS_SYNTAX
+} rasqal_query_results_type;
+
+
+/**
+ * rasqal_update_type:
+ * @RASQAL_UPDATE_TYPE_CLEAR: Clear graph.
+ * @RASQAL_UPDATE_TYPE_CREATE: Create graph.
+ * @RASQAL_UPDATE_TYPE_DROP: Drop graph.
+ * @RASQAL_UPDATE_TYPE_LOAD: Load graph.
+ * @RASQAL_UPDATE_TYPE_UPDATE: Insert or Delete graph or triples.
+ * @RASQAL_UPDATE_TYPE_UNKNOWN: Internal
+ * @RASQAL_UPDATE_TYPE_LAST: Internal
+ *
+ * Update type being performed.
+ *
+ */
+typedef enum {
+  /* internal */
+  RASQAL_UPDATE_TYPE_UNKNOWN   = 0,
+  RASQAL_UPDATE_TYPE_CLEAR     = 1,
+  RASQAL_UPDATE_TYPE_CREATE    = 2,
+  RASQAL_UPDATE_TYPE_DROP      = 3,
+  RASQAL_UPDATE_TYPE_LOAD      = 4,
+  RASQAL_UPDATE_TYPE_UPDATE    = 5,
+
+  /* internal */
+  RASQAL_UPDATE_TYPE_LAST = RASQAL_UPDATE_TYPE_UPDATE
+} rasqal_update_type;
+
+
+/**
+ * rasqal_update_flags:
+ * @RASQAL_UPDATE_FLAGS_SILENT: the update operation should be silent
+ * @RASQAL_UPDATE_FLAGS_DATA: the update operation is triple data not templates
+ *
+ * Flags for graph update operations
+ */
+typedef enum {
+  RASQAL_UPDATE_FLAGS_SILENT = 1,
+  RASQAL_UPDATE_FLAGS_DATA = 2,
+} rasqal_update_flags;
+
+
+/**
+ * rasqal_update_operation:
+ * @type: type of update
+ * @graph_uri: optional graph URI (clear, drop, load, with ... delete/insert)
+ * @document_uri: optional document URI (load)
+ * @insert_templates: optional sequence of triple templates to insert
+ * @delete_templates: optional sequence of triple templates to delete
+ * @where: optional where template (insert/delete)
+ * @flags: update flags - bit-or of flags defined in #rasqal_update_flags
+ *
+ * Update operation - changing the dataset
+ *
+ */
+typedef struct {
+  rasqal_update_type type;
+
+  raptor_uri* graph_uri;
+
+  raptor_uri* document_uri;
+
+  raptor_sequence* insert_templates;
+
+  raptor_sequence* delete_templates;
+
+  rasqal_graph_pattern* where;
+
+  int flags;
+} rasqal_update_operation;
+
+
 /**
  * rasqal_graph_pattern_operator:
  * @RASQAL_GRAPH_PATTERN_OPERATOR_BASIC: Just triple patterns and constraints.
@@ -834,6 +943,12 @@ void rasqal_query_graph_pattern_visit(rasqal_query* query, rasqal_graph_pattern_
 RASQAL_API
 int rasqal_query_write(raptor_iostream* iostr, rasqal_query* query, raptor_uri* format_uri, raptor_uri* base_uri);
 
+/* update */
+RASQAL_API
+raptor_sequence* rasqal_query_get_update_operations_sequence(rasqal_query* query);
+RASQAL_API
+rasqal_update_operation* rasqal_query_get_update_operation(rasqal_query* query, int idx);
+
 /* graph patterns */
 RASQAL_API
 rasqal_graph_pattern* rasqal_query_get_query_graph_pattern(rasqal_query* query);
@@ -854,7 +969,7 @@ rasqal_graph_pattern_operator rasqal_graph_pattern_get_operator(rasqal_graph_pat
 RASQAL_API
 const char* rasqal_graph_pattern_operator_as_string(rasqal_graph_pattern_operator op);
 RASQAL_API
-void rasqal_graph_pattern_print(rasqal_graph_pattern* gp, FILE* fh);
+int rasqal_graph_pattern_print(rasqal_graph_pattern* gp, FILE* fh);
 RASQAL_API
 int rasqal_graph_pattern_set_filter_expression(rasqal_graph_pattern* gp, rasqal_expression* expr);
 RASQAL_API
@@ -872,7 +987,7 @@ rasqal_literal* rasqal_graph_pattern_get_origin(rasqal_graph_pattern* graph_patt
 RASQAL_API
 const char* rasqal_query_verb_as_string(rasqal_query_verb verb);
 RASQAL_API
-void rasqal_query_print(rasqal_query* query, FILE* fh);
+int rasqal_query_print(rasqal_query* query, FILE* fh);
 
 /* Query */
 RASQAL_API
@@ -887,6 +1002,8 @@ void rasqal_query_set_user_data(rasqal_query* query, void *user_data);
 
 /* query results */
 RASQAL_API
+rasqal_query_results* rasqal_new_query_results(rasqal_world* world, rasqal_query* query, rasqal_query_results_type type, rasqal_variables_table* vars_table);
+RASQAL_API
 void rasqal_free_query_results(rasqal_query_results *query_results);
 
 RASQAL_API
@@ -911,6 +1028,8 @@ RASQAL_API
 rasqal_literal* rasqal_query_results_get_binding_value_by_name(rasqal_query_results *query_results, const unsigned char *name);
 RASQAL_API
 int rasqal_query_results_get_bindings_count(rasqal_query_results *query_results);
+RASQAL_API
+int rasqal_query_results_add_row(rasqal_query_results* query_results, rasqal_row* row);
 
 /* Boolean result format */
 RASQAL_API
@@ -930,10 +1049,14 @@ int rasqal_query_results_next_triple(rasqal_query_results *query_results);
 RASQAL_API
 int rasqal_query_results_is_syntax(rasqal_query_results* query_results);
 
-RASQAL_API
+RASQAL_API RASQAL_DEPRECATED
 int rasqal_query_results_write(raptor_iostream *iostr, rasqal_query_results *results, raptor_uri *format_uri, raptor_uri *base_uri);
 RASQAL_API
+int rasqal_query_results_write2(raptor_iostream *iostr, rasqal_query_results *results, const char* name, const char* mime_type, raptor_uri *format_uri, raptor_uri *base_uri);
+RASQAL_API RASQAL_DEPRECATED
 int rasqal_query_results_read(raptor_iostream *iostr, rasqal_query_results *results, raptor_uri *format_uri, raptor_uri *base_uri);
+RASQAL_API
+int rasqal_query_results_read2(raptor_iostream *iostr, rasqal_query_results *results, const char* name, const char* mime_type, raptor_uri *format_uri, raptor_uri *base_uri);
 
 
 /**
@@ -955,8 +1078,10 @@ int rasqal_query_results_formats_enumerate(rasqal_world* world, unsigned int cou
 RASQAL_API
 int rasqal_query_results_formats_check(rasqal_world* world, const char *name, raptor_uri* uri, const char *mime_type);
 RASQAL_API
+rasqal_query_results_formatter* rasqal_new_query_results_formatter2(rasqal_world* world, const char *name, const char *mime_type, raptor_uri* format_uri);
+RASQAL_API RASQAL_DEPRECATED
 rasqal_query_results_formatter* rasqal_new_query_results_formatter(rasqal_world* world, const char *name, raptor_uri* format_uri);
-RASQAL_API
+RASQAL_API RASQAL_DEPRECATED
 rasqal_query_results_formatter* rasqal_new_query_results_formatter_by_mime_type(rasqal_world* world, const char *mime_type);
 RASQAL_API
 void rasqal_free_query_results_formatter(rasqal_query_results_formatter* formatter);
@@ -979,7 +1104,7 @@ rasqal_data_graph* rasqal_new_data_graph(rasqal_world* world, raptor_uri* uri, r
 RASQAL_API
 void rasqal_free_data_graph(rasqal_data_graph* dg);
 RASQAL_API
-void rasqal_data_graph_print(rasqal_data_graph* dg, FILE* fh);
+int rasqal_data_graph_print(rasqal_data_graph* dg, FILE* fh);
 
 
 /**
@@ -1030,7 +1155,7 @@ void rasqal_free_expression(rasqal_expression* e);
 RASQAL_API
 void rasqal_expression_print_op(rasqal_expression* e, FILE* fh);
 RASQAL_API
-void rasqal_expression_print(rasqal_expression* e, FILE* fh);
+int rasqal_expression_print(rasqal_expression* e, FILE* fh);
 RASQAL_API
 rasqal_literal* rasqal_expression_evaluate(rasqal_world *world, raptor_locator *locator, rasqal_expression* e, int flags);
 
@@ -1080,7 +1205,7 @@ rasqal_literal* rasqal_new_literal_from_literal(rasqal_literal* l);
 RASQAL_API
 void rasqal_free_literal(rasqal_literal* l);
 RASQAL_API
-void rasqal_literal_print(rasqal_literal* l, FILE* fh);
+int rasqal_literal_print(rasqal_literal* l, FILE* fh);
 RASQAL_API
 void rasqal_literal_print_type(rasqal_literal* l, FILE* fh);
 RASQAL_API
@@ -1113,7 +1238,14 @@ rasqal_prefix* rasqal_new_prefix(rasqal_world* world, const unsigned char* prefi
 RASQAL_API
 void rasqal_free_prefix(rasqal_prefix* p);
 RASQAL_API
-void rasqal_prefix_print(rasqal_prefix* p, FILE* fh);
+int rasqal_prefix_print(rasqal_prefix* p, FILE* fh);
+
+
+/* Row class */
+rasqal_row* rasqal_new_row_for_size(rasqal_world* world, int size);
+void rasqal_free_row(rasqal_row* row);
+int rasqal_row_set_value_at(rasqal_row* row, int offset, rasqal_literal* value);
+
 
 /* Triple class */
 RASQAL_API
@@ -1123,7 +1255,7 @@ rasqal_triple* rasqal_new_triple_from_triple(rasqal_triple* t);
 RASQAL_API
 void rasqal_free_triple(rasqal_triple* t);
 RASQAL_API
-void rasqal_triple_print(rasqal_triple* t, FILE* fh);
+int rasqal_triple_print(rasqal_triple* t, FILE* fh);
 RASQAL_API
 void rasqal_triple_set_origin(rasqal_triple* t, rasqal_literal *l);
 RASQAL_API
@@ -1139,10 +1271,20 @@ rasqal_variable* rasqal_new_variable_from_variable(rasqal_variable* v);
 RASQAL_API
 void rasqal_free_variable(rasqal_variable* v);
 RASQAL_API
-void rasqal_variable_print(rasqal_variable* v, FILE* fh);
+int rasqal_variable_print(rasqal_variable* v, FILE* fh);
 RASQAL_API
 void rasqal_variable_set_value(rasqal_variable* v, rasqal_literal* l);
 
+
+/* Variables Table */
+RASQAL_API
+rasqal_variables_table* rasqal_new_variables_table(rasqal_world* world);
+RASQAL_API
+void rasqal_free_variables_table(rasqal_variables_table* vt);
+RASQAL_API
+rasqal_variable* rasqal_variables_table_add(rasqal_variables_table* vt, rasqal_variable_type type, const unsigned char *name, rasqal_literal *value);
+
+
 /* memory functions */
 RASQAL_API
 void rasqal_free_memory(void *ptr);
