@@ -54,347 +54,6 @@
 #ifndef STANDALONE
 
 
-/**
- * rasqal_new_data_graph:
- * @world: rasqal_world object
- * @uri: source URI
- * @name_uri: name of graph (or NULL)
- * @flags: %RASQAL_DATA_GRAPH_NAMED or %RASQAL_DATA_GRAPH_BACKGROUND
- * 
- * Constructor - create a new #rasqal_data_graph.
- * 
- * The name_uri is only used when the flags are %RASQAL_DATA_GRAPH_NAMED.
- * 
- * Return value: a new #rasqal_data_graph or NULL on failure.
- **/
-rasqal_data_graph*
-rasqal_new_data_graph(rasqal_world* world, raptor_uri* uri, raptor_uri* name_uri, int flags)
-{
-  rasqal_data_graph* dg = (rasqal_data_graph*)RASQAL_CALLOC(rasqal_data_graph, 1,
-                                                            sizeof(rasqal_data_graph));
-  if(dg) {
-    dg->world = world;
-#ifdef RAPTOR_V2_AVAILABLE
-    dg->uri = raptor_uri_copy_v2(world->raptor_world_ptr, uri);
-    if(name_uri)
-      dg->name_uri = raptor_uri_copy_v2(world->raptor_world_ptr, name_uri);
-#else
-    dg->uri = raptor_uri_copy(uri);
-    if(name_uri)
-      dg->name_uri = raptor_uri_copy(name_uri);
-#endif
-    dg->flags = flags;
-  }
-
-  return dg;
-}
-
-
-/**
- * rasqal_free_data_graph:
- * @dg: #rasqal_data_graph object
- * 
- * Destructor - destroy a #rasqal_data_graph object.
- *
- **/
-void
-rasqal_free_data_graph(rasqal_data_graph* dg)
-{
-  RASQAL_ASSERT_OBJECT_POINTER_RETURN(dg, rasqal_data_graph);
-
-#ifdef RAPTOR_V2_AVAILABLE  
-  if(dg->uri)
-    raptor_free_uri_v2(dg->world->raptor_world_ptr, dg->uri);
-  if(dg->name_uri)
-    raptor_free_uri_v2(dg->world->raptor_world_ptr, dg->name_uri);
-#else
-  if(dg->uri)
-    raptor_free_uri(dg->uri);
-  if(dg->name_uri)
-    raptor_free_uri(dg->name_uri);
-#endif
-  RASQAL_FREE(rasqal_data_graph, dg);
-}
-
-
-/**
- * rasqal_data_graph_print:
- * @dg: #rasqal_data_graph object
- * @fh: the #FILE* handle to print to
- *
- * Print a Rasqal data graph in a debug format.
- * 
- * The print debug format may change in any release.
- **/
-void
-rasqal_data_graph_print(rasqal_data_graph* dg, FILE* fh)
-{
-#ifdef RAPTOR_V2_AVAILABLE
-  if(dg->name_uri)
-    fprintf(fh, "data graph(%s named as %s flags %d)", 
-            raptor_uri_as_string_v2(dg->world->raptor_world_ptr, dg->uri),
-            raptor_uri_as_string_v2(dg->world->raptor_world_ptr, dg->name_uri),
-            dg->flags);
-  else
-    fprintf(fh, "data graph(%s, flags %d)", 
-            raptor_uri_as_string_v2(dg->world->raptor_world_ptr, dg->uri), dg->flags);
-#else
-  if(dg->name_uri)
-    fprintf(fh, "data graph(%s named as %s flags %d)", 
-            raptor_uri_as_string(dg->uri),
-            raptor_uri_as_string(dg->name_uri),
-            dg->flags);
-  else
-    fprintf(fh, "data graph(%s, flags %d)", 
-            raptor_uri_as_string(dg->uri), dg->flags);
-#endif
-}
-
-
-/**
- * rasqal_new_prefix:
- * @world: rasqal_world object
- * @prefix: Short prefix string to stand for URI or NULL.
- * @uri: Name #raptor_uri.
- * 
- * Constructor - create a new #rasqal_prefix.
- * Takes ownership of prefix and uri.
- * 
- * Return value: a new #rasqal_prefix or NULL on failure.
- **/
-rasqal_prefix*
-rasqal_new_prefix(rasqal_world* world, const unsigned char *prefix, raptor_uri* uri) 
-{
-  rasqal_prefix* p = (rasqal_prefix*)RASQAL_CALLOC(rasqal_prefix, 1,
-                                                   sizeof(rasqal_prefix));
-
-  if(p) {  
-    p->world = world;
-    p->prefix = prefix;
-    p->uri = uri;
-  } else {
-    RASQAL_FREE(cstring, prefix);
-#ifdef RAPTOR_V2_AVAILABLE
-    raptor_free_uri_v2(world->raptor_world_ptr, uri);
-#else
-    raptor_free_uri(uri);
-#endif
-  }
-
-  return p;
-}
-
-
-/**
- * rasqal_free_prefix:
- * @p: #rasqal_prefix object.
- * 
- * Destructor - destroy a #rasqal_prefix object.
- **/
-void
-rasqal_free_prefix(rasqal_prefix* p)
-{
-  RASQAL_ASSERT_OBJECT_POINTER_RETURN(p, rasqal_prefix);
-  
-  if(p->prefix)
-    RASQAL_FREE(cstring, (void*)p->prefix);
-  if(p->uri)
-#ifdef RAPTOR_V2_AVAILABLE
-    raptor_free_uri_v2(p->world->raptor_world_ptr, p->uri);
-#else
-    raptor_free_uri(p->uri);
-#endif
-  RASQAL_FREE(rasqal_prefix, p);
-}
-
-
-/**
- * rasqal_prefix_print:
- * @p: #rasqal_prefix object.
- * @fh: The #FILE* handle to print to.
- *
- * Print a Rasqal prefix in a debug format.
- * 
- * The print debug format may change in any release.
- **/
-void
-rasqal_prefix_print(rasqal_prefix* p, FILE* fh)
-{
-  fprintf(fh, "prefix(%s as %s)", (p->prefix ? (const char*)p->prefix : "(default)"),
-#ifdef RAPTOR_V2_AVAILABLE
-          raptor_uri_as_string_v2(p->world->raptor_world_ptr, p->uri)
-#else
-          raptor_uri_as_string(p->uri)
-#endif
-          );
-}
-
-
-
-/**
- * rasqal_new_triple:
- * @subject: Triple subject.
- * @predicate: Triple predicate.
- * @object: Triple object.
- * 
- * Constructor - create a new #rasqal_triple triple or triple pattern.
- * Takes ownership of the literals passed in.
- * 
- * The triple origin can be set with rasqal_triple_set_origin().
- *
- * Return value: a new #rasqal_triple or NULL on failure.
- **/
-rasqal_triple*
-rasqal_new_triple(rasqal_literal* subject, rasqal_literal* predicate, rasqal_literal* object)
-{
-  rasqal_triple* t=(rasqal_triple*)RASQAL_CALLOC(rasqal_triple, 1, sizeof(rasqal_triple));
-
-  if(t) {
-    t->subject=subject;
-    t->predicate=predicate;
-    t->object=object;
-  } else {
-    if(subject)
-      rasqal_free_literal(subject);
-    if(predicate)
-      rasqal_free_literal(predicate);
-    if(object)
-      rasqal_free_literal(object);
-  }
-
-  return t;
-}
-
-
-/**
- * rasqal_new_triple_from_triple:
- * @t: Triple to copy.
- * 
- * Copy constructor - create a new #rasqal_triple from an existing one.
- * 
- * Return value: a new #rasqal_triple or NULL on failure.
- **/
-rasqal_triple*
-rasqal_new_triple_from_triple(rasqal_triple* t)
-{
-  rasqal_triple* newt=(rasqal_triple*)RASQAL_CALLOC(rasqal_triple, 1, sizeof(rasqal_triple));
-
-  if(newt) {
-    newt->subject=rasqal_new_literal_from_literal(t->subject);
-    newt->predicate=rasqal_new_literal_from_literal(t->predicate);
-    newt->object=rasqal_new_literal_from_literal(t->object);
-  }
-
-  return newt;
-}
-
-
-/**
- * rasqal_free_triple:
- * @t: #rasqal_triple object.
- * 
- * Destructor - destroy a #rasqal_triple object.
- **/
-void
-rasqal_free_triple(rasqal_triple* t)
-{
-  RASQAL_ASSERT_OBJECT_POINTER_RETURN(t, rasqal_triple);
-  
-  if(t->subject)
-    rasqal_free_literal(t->subject);
-  if(t->predicate)
-    rasqal_free_literal(t->predicate);
-  if(t->object)
-    rasqal_free_literal(t->object);
-  if(t->origin)
-    rasqal_free_literal(t->origin);
-  RASQAL_FREE(rasqal_triple, t);
-}
-
-
-/**
- * rasqal_triple_write:
- * @t: #rasqal_triple object.
- * @iostr: The #raptor_iostream handle to write to.
- * 
- * Write a Rasqal triple to an iostream in a debug format.
- * 
- * The print debug format may change in any release.
- **/
-void
-rasqal_triple_write(rasqal_triple* t, raptor_iostream* iostr)
-{
-  raptor_iostream_write_counted_string(iostr, "triple(", 7);
-  rasqal_literal_write(t->subject, iostr);
-  raptor_iostream_write_counted_string(iostr, ", ", 2);
-  rasqal_literal_write(t->predicate, iostr);
-  raptor_iostream_write_counted_string(iostr, ", ", 2);
-  rasqal_literal_write(t->object, iostr);
-  raptor_iostream_write_byte(iostr, ')');
-  if(t->origin) {
-    raptor_iostream_write_counted_string(iostr, " with origin(", 13);
-    rasqal_literal_write(t->origin, iostr);
-    raptor_iostream_write_byte(iostr, ')');
-  }
-}
-
-
-/**
- * rasqal_triple_print:
- * @t: #rasqal_triple object.
- * @fh: The #FILE* handle to print to.
- * 
- * Print a Rasqal triple in a debug format.
- * 
- * The print debug format may change in any release.
- **/
-void
-rasqal_triple_print(rasqal_triple* t, FILE* fh)
-{
-  fputs("triple(", fh);
-  rasqal_literal_print(t->subject, fh);
-  fputs(", ", fh);
-  rasqal_literal_print(t->predicate, fh);
-  fputs(", ", fh);
-  rasqal_literal_print(t->object, fh);
-  fputc(')', fh);
-  if(t->origin) {
-    fputs(" with origin(", fh);
-    rasqal_literal_print(t->origin, fh);
-    fputc(')', fh);
-  }
-}
-
-
-/**
- * rasqal_triple_set_origin:
- * @t: The triple object. 
- * @l: The #rasqal_literal object to set as origin.
- * 
- * Set the origin field of a #rasqal_triple.
- **/
-void
-rasqal_triple_set_origin(rasqal_triple* t, rasqal_literal* l)
-{
-  t->origin=l;
-}
-
-
-/**
- * rasqal_triple_get_origin:
- * @t: The triple object. 
- * 
- * Get the origin field of a #rasqal_triple.
- * 
- * Return value: The triple origin or NULL.
- **/
-rasqal_literal*
-rasqal_triple_get_origin(rasqal_triple* t)
-{
-  return t->origin;
-}
-
-
 /**
  * rasqal_new_0op_expression:
  * @world: rasqal_world object
@@ -412,7 +71,11 @@ rasqal_triple_get_origin(rasqal_triple* t)
 rasqal_expression*
 rasqal_new_0op_expression(rasqal_world* world, rasqal_op op)
 {
-  rasqal_expression* e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(rasqal_expression));
+  rasqal_expression* e;
+
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(world, rasqal_world, NULL);
+
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -452,11 +115,10 @@ rasqal_new_1op_expression(rasqal_world* world, rasqal_op op, rasqal_expression*
 {
   rasqal_expression* e = NULL;
 
-  if(!arg)
+  if(!world || !arg)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -502,11 +164,10 @@ rasqal_new_2op_expression(rasqal_world* world,
 {
   rasqal_expression* e = NULL;
 
-  if(!arg1 || !arg2)
+  if(!world || !arg1 || !arg2)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, 
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -550,11 +211,10 @@ rasqal_new_3op_expression(rasqal_world* world,
 {
   rasqal_expression* e = NULL;
 
-  if(!arg1 || !arg2) /* arg3 may be NULL */
+  if(!world || !arg1 || !arg2) /* arg3 may be NULL */
     goto tidy;
 
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -600,11 +260,10 @@ rasqal_new_string_op_expression(rasqal_world* world,
 {
   rasqal_expression* e = NULL;
 
-  if(!arg1 || !literal)
+  if(!world || !arg1 || !literal)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -638,11 +297,10 @@ rasqal_new_literal_expression(rasqal_world* world, rasqal_literal *literal)
 {
   rasqal_expression* e;
 
-  if(!literal)
+  if(!world || !literal)
     return NULL;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                         sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {  
     e->usage = 1;
     e->world = world;
@@ -673,11 +331,10 @@ rasqal_new_function_expression(rasqal_world* world,
 {
   rasqal_expression* e = NULL;
 
-  if(!name || !args)
+  if(!world || !name || !args)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -688,11 +345,7 @@ rasqal_new_function_expression(rasqal_world* world,
   
   tidy:
   if(name)
-#ifdef RAPTOR_V2_AVAILABLE
-    raptor_free_uri_v2(world->raptor_world_ptr, name);
-#else
     raptor_free_uri(name);
-#endif
   if(args)
     raptor_free_sequence(args);
 
@@ -712,15 +365,15 @@ rasqal_new_function_expression(rasqal_world* world,
  * Return value: a new #rasqal_expression object or NULL on failure
  **/
 rasqal_expression*
-rasqal_new_cast_expression(rasqal_world* world, raptor_uri* name, rasqal_expression *value) 
+rasqal_new_cast_expression(rasqal_world* world, raptor_uri* name,
+                           rasqal_expression *value) 
 {
   rasqal_expression* e = NULL;
 
-  if(!name || !value)
+  if(!world || !name || !value)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -731,11 +384,7 @@ rasqal_new_cast_expression(rasqal_world* world, raptor_uri* name, rasqal_express
 
   tidy:
   if(name)
-#ifdef RAPTOR_V2_AVAILABLE
-    raptor_free_uri_v2(world->raptor_world_ptr, name);
-#else
     raptor_free_uri(name);
-#endif
   if(value)
     rasqal_free_expression(value);
 
@@ -759,11 +408,10 @@ rasqal_new_coalesce_expression(rasqal_world* world, raptor_sequence* args)
 {
   rasqal_expression* e = NULL;
 
-  if(!args)
+  if(!world || !args)
     goto tidy;
   
-  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1,
-                                        sizeof(rasqal_expression));
+  e = (rasqal_expression*)RASQAL_CALLOC(rasqal_expression, 1, sizeof(*e));
   if(e) {
     e->usage = 1;
     e->world = world;
@@ -791,6 +439,8 @@ rasqal_new_coalesce_expression(rasqal_world* world, raptor_sequence* args)
 void
 rasqal_expression_clear(rasqal_expression* e)
 {
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(e, rasqal_expression);
+
   switch(e->op) {
     case RASQAL_EXPR_AND:
     case RASQAL_EXPR_OR:
@@ -847,19 +497,11 @@ rasqal_expression_clear(rasqal_expression* e)
       rasqal_free_literal(e->literal);
       break;
     case RASQAL_EXPR_FUNCTION:
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_free_uri_v2(e->world->raptor_world_ptr, e->name);
-#else
       raptor_free_uri(e->name);
-#endif
       raptor_free_sequence(e->args);
       break;
     case RASQAL_EXPR_CAST:
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_free_uri_v2(e->world->raptor_world_ptr, e->name);
-#else
       raptor_free_uri(e->name);
-#endif
       rasqal_free_expression(e->arg1);
       break;
 
@@ -880,18 +522,18 @@ rasqal_expression_clear(rasqal_expression* e)
 
 /**
  * rasqal_new_expression_from_expression:
- * @e: #rasqal_expression object to copy
+ * @e: #rasqal_expression object to copy or NULL
  *
  * Copy Constructor - create a new #rasqal_expression object from an existing rasqal_expression object.
  * 
- * Return value: a new #rasqal_expression object or NULL on failure
+ * Return value: a new #rasqal_expression object or NULL if @e is NULL
  **/
 rasqal_expression*
 rasqal_new_expression_from_expression(rasqal_expression* e)
 {
   if(!e)
     return NULL;
-  
+
   e->usage++;
   return e;
 }
@@ -937,8 +579,11 @@ rasqal_expression_visit(rasqal_expression* e,
   int i;
   int result=0;
 
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(e, rasqal_expression, 1);
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(fn, rasqal_expression_visit_fn, 1);
+
   /* This ordering allows fn to potentially edit 'e' in-place */
-  result=fn(user_data, e);
+  result = fn(user_data, e);
   if(result)
     return result;
 
@@ -1228,7 +873,13 @@ rasqal_expression_evaluate_strmatch(rasqal_world *world,
 #endif
 
 #ifdef RASQAL_REGEX_NONE
-  rasqal_log_error_simple(world, RAPTOR_LOG_LEVEL_WARNING, locator,
+  rasqal_log_error_simple(world,
+#ifdef RAPTOR_V2_AVAILABLE
+                          RAPTOR_LOG_LEVEL_WARN,
+#else
+                          RAPTOR_LOG_LEVEL_WARNING,
+#endif
+                          locator,
                           "Regex support missing, cannot compare '%s' to '%s'", match_string, pattern);
   b=1;
   rc= -1;
@@ -1259,7 +910,7 @@ rasqal_expression_evaluate_strmatch(rasqal_world *world,
 /**
  * rasqal_expression_evaluate:
  * @world: #rasqal_world
- * @locator: error locator
+ * @locator: error locator (or NULL)
  * @e: The expression to evaluate.
  * @flags: Flags for rasqal_literal_compare() and RASQAL_COMPARE_NOCASE for string matches.
  * 
@@ -1272,8 +923,7 @@ rasqal_literal*
 rasqal_expression_evaluate(rasqal_world *world, raptor_locator *locator,
                            rasqal_expression* e, int flags)
 {
-  rasqal_literal* result=NULL;
-
+  rasqal_literal* result = NULL;
   rasqal_literal *l1;
   rasqal_literal *l2;
   const unsigned char *s;
@@ -1294,7 +944,10 @@ rasqal_expression_evaluate(rasqal_world *world, raptor_locator *locator,
     rasqal_variable *v;
   } vars;
 
-  errs.e=0;
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(world, rasqal_world, NULL);
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(e, rasqal_expression, NULL);
+
+  errs.e = 0;
 
 #ifdef RASQAL_DEBUG
   RASQAL_DEBUG2("evaluating expression %p: ", e);
@@ -1681,11 +1334,7 @@ rasqal_expression_evaluate(rasqal_world *world, raptor_locator *locator,
         goto failed;
       }
       
-#ifdef RAPTOR_V2_AVAILABLE
-      result = rasqal_new_uri_literal(world, raptor_uri_copy_v2(world->raptor_world_ptr, vars.dt_uri));
-#else
       result = rasqal_new_uri_literal(world, raptor_uri_copy(vars.dt_uri));
-#endif
 
       if(errs.flags.free_literal)
         rasqal_free_literal(l1);
@@ -1949,7 +1598,13 @@ rasqal_expression_evaluate(rasqal_world *world, raptor_locator *locator,
       break;
 
     case RASQAL_EXPR_FUNCTION:
-      rasqal_log_error_simple(world, RAPTOR_LOG_LEVEL_WARNING, locator,
+      rasqal_log_error_simple(world,
+#ifdef RAPTOR_V2_AVAILABLE
+                              RAPTOR_LOG_LEVEL_WARN,
+#else
+                              RAPTOR_LOG_LEVEL_WARNING,
+#endif
+                              locator,
                               "No function expressions support at present.  Returning false.");
       result=rasqal_new_boolean_literal(world, 0);
       break;
@@ -2107,9 +1762,13 @@ static const char* const rasqal_op_labels[RASQAL_EXPR_LAST+1]={
 void
 rasqal_expression_write_op(rasqal_expression* e, raptor_iostream* iostr)
 {
-  rasqal_op op=e->op;
+  rasqal_op op;
+
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(e, rasqal_expression);
+
+  op = e->op;
   if(op > RASQAL_EXPR_LAST)
-    op=RASQAL_EXPR_UNKNOWN;
+    op = RASQAL_EXPR_UNKNOWN;
   raptor_iostream_write_string(iostr, rasqal_op_labels[(int)op]);
 }
 
@@ -2117,7 +1776,7 @@ rasqal_expression_write_op(rasqal_expression* e, raptor_iostream* iostr)
 /**
  * rasqal_expression_print_op:
  * @e: the #rasqal_expression object
- * @fh: the #FILE* handle to print to
+ * @fh: the FILE* handle to print to
  * 
  * Print a rasqal expression operator in a debug format.
  *
@@ -2126,9 +1785,14 @@ rasqal_expression_write_op(rasqal_expression* e, raptor_iostream* iostr)
 void
 rasqal_expression_print_op(rasqal_expression* e, FILE* fh)
 {
-  rasqal_op op=e->op;
+  rasqal_op op;
+
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(e, rasqal_expression);
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(fh, FILE*);
+
+  op = e->op;
   if(op > RASQAL_EXPR_LAST)
-    op=RASQAL_EXPR_UNKNOWN;
+    op = RASQAL_EXPR_UNKNOWN;
   fputs(rasqal_op_labels[(int)op], fh);
 }
 
@@ -2147,6 +1811,9 @@ rasqal_expression_write(rasqal_expression* e, raptor_iostream* iostr)
 {
   int i;
   
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(e, rasqal_expression);
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN(iostr, raptor_iostr);
+
   raptor_iostream_write_counted_string(iostr, "expr(", 5);
   switch(e->op) {
     case RASQAL_EXPR_AND:
@@ -2222,11 +1889,7 @@ rasqal_expression_write(rasqal_expression* e, raptor_iostream* iostr)
 
     case RASQAL_EXPR_FUNCTION:
       raptor_iostream_write_counted_string(iostr, "function(uri=", 13);
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_iostream_write_uri_v2(e->world->raptor_world_ptr, iostr, e->name);
-#else
       raptor_iostream_write_uri(iostr, e->name);
-#endif
       raptor_iostream_write_counted_string(iostr, ", args=", 7);
       for(i=0; i<raptor_sequence_size(e->args); i++) {
         rasqal_expression* e2;
@@ -2240,11 +1903,7 @@ rasqal_expression_write(rasqal_expression* e, raptor_iostream* iostr)
 
     case RASQAL_EXPR_CAST:
       raptor_iostream_write_counted_string(iostr, "cast(type=", 10);
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_iostream_write_uri_v2(e->world->raptor_world_ptr, iostr, e->name);
-#else
       raptor_iostream_write_uri(iostr, e->name);
-#endif
       raptor_iostream_write_counted_string(iostr, ", value=", 8);
       rasqal_expression_write(e->arg1, iostr);
       raptor_iostream_write_byte(iostr, ')');
@@ -2277,15 +1936,20 @@ rasqal_expression_write(rasqal_expression* e, raptor_iostream* iostr)
 /**
  * rasqal_expression_print:
  * @e: #rasqal_expression object.
- * @fh: The #FILE* handle to print to.
+ * @fh: The FILE* handle to print to.
  * 
  * Print a Rasqal expression in a debug format.
  * 
  * The print debug format may change in any release.
+ *
+ * Return value: non-0 on failure
  **/
-void
+int
 rasqal_expression_print(rasqal_expression* e, FILE* fh)
 {
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(e, rasqal_expression, 1);
+  RASQAL_ASSERT_OBJECT_POINTER_RETURN_VALUE(fh, FILE*, 1);
+
   fputs("expr(", fh);
   switch(e->op) {
     case RASQAL_EXPR_AND:
@@ -2361,11 +2025,7 @@ rasqal_expression_print(rasqal_expression* e, FILE* fh)
 
     case RASQAL_EXPR_FUNCTION:
       fputs("function(uri=", fh);
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_uri_print_v2(e->world->raptor_world_ptr, e->name, fh);
-#else
       raptor_uri_print(e->name, fh);
-#endif
       fputs(", args=", fh);
       raptor_sequence_print(e->args, fh);
       fputc(')', fh);
@@ -2373,11 +2033,7 @@ rasqal_expression_print(rasqal_expression* e, FILE* fh)
 
     case RASQAL_EXPR_CAST:
       fputs("cast(type=", fh);
-#ifdef RAPTOR_V2_AVAILABLE
-      raptor_uri_print_v2(e->world->raptor_world_ptr, e->name, fh);
-#else
       raptor_uri_print(e->name, fh);
-#endif
       fputs(", value=", fh);
       rasqal_expression_print(e->arg1, fh);
       fputc(')', fh);
@@ -2398,6 +2054,8 @@ rasqal_expression_print(rasqal_expression* e, FILE* fh)
       RASQAL_FATAL2("Unknown operation %d", e->op);
   }
   fputc(')', fh);
+
+  return 0;
 }
 
 
